from .base_error import BaseError


class ParseModelNamespaceError(BaseError):
    def __init__(self, message: str = None, *args: object) -> None:
        super().__init__('PARSE_NAMESPACE', message, *args)

class MissedRepresentationError(BaseError):
    def __init__(self, message: str = None, *args: object) -> None:
        super().__init__('MISSED_REPRESENTATION', message, *args)

class ObjectAlreadyExistsError(BaseError):
    def __init__(self, message: str = None, *args: object) -> None:
        super().__init__('OBJECT_ALREADY_EXISTS', message, *args)

class RequiredFieldError(BaseError):
    def __init__(self, message: str = None, *args: object) -> None:
        super().__init__('REQUIRED_FIELD', message, *args)

class ObjectNotFoundError(BaseError):
    def __init__(self, message: str = None, *args: object) -> None:
        super().__init__('OBJECT_NOT_FOUND', message, *args)



class DataFilter:
    page_no: int
    page_size: int
    fields: dict
    order_by: str
    order_direction: str

    def __init__(self, page_no = 0, page_size = 25, fields = {}, order_by = 'created_at', order_direction = 'asc'):
        self.page_no = page_no
        self.page_size = page_size
        self.fields = fields
        self.order_by = order_by
        self.order_direction = order_direction

    @classmethod
    def from_dict(cls, filter: dict):
        filter.setdefault('page_no', 0)
        filter.setdefault('page_size', 25)
        filter.setdefault('order_by', 'created_at')
        filter.setdefault('order_direction', 'asc')
        filter.setdefault('fields', {})

        return cls(**filter)
